import { select,csv,
        scaleLinear,max,extent,axisLeft,
        axisBottom, format} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data =>{
  const xValue = d => d.mpg;
  const yValue = d => d.horsepower;
  
  const margin = {top:50, right:70, bottom:250, left:200}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = width - margin.top - margin.bottom;
  const circleRadius = 5;
  const xAixaLabel = 'Mpg';
  const yAixaLabel = 'Horsepower';
  const title = 'Cars: ' + yAixaLabel + ' vs. '
  + xAixaLabel;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
		.domain(extent(data, yValue))
  	// .range([0, innerHeight])
  	.range([innerHeight, 0])
  	.nice();
  
  const yAxis = axisLeft(yScale);
  const xAxis = axisBottom(xScale);
  
  yAxis.tickSize(-innerWidth)
  	.tickPadding(10);
  
  xAxis.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  // yAxis(g.append('g'));
  
  // fixed yAxis
  const yAixsG = g.append('g').call(yAxis);
  yAixsG.selectAll('.domain').remove();
  yAixsG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -70)
  	.attr('x', -innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('transform', 'rotate(-90)')
  	.style('text-anchor', 'middle')
  	.text(yAixaLabel);
  
  
  // fixed xAxis
  const xAxisG = g.append('g').call(xAxis)
		.attr('transform',`translate(0,${innerHeight})`)
  	
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 80)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text(xAixaLabel);
  
	g.selectAll('circle').data(data)
	.enter().append('circle')
	.attr('cy', d=>yScale(yValue(d)))
	.attr('cx', d=>xScale(xValue(d)))
	.attr('r', circleRadius);
  
  // add title
  g.append('text')
  	.attr('class', 'title')
  	.attr('x', 20)
  	.attr('y', -12)
  	.text(title);
};


// csv('data.csv').then(data=>{
csv('https://vizhub.com/curran/datasets/auto-mpg.csv').then(data=>{
  data.forEach(d=>{
  	d.mpg = +d.mpg;
  	d.cylinders = +d.cylinders;
  	d.displacement = +d.displacement;
  	d.horsepower = +d.horsepower;
  	d.accelerating = +d.accelerating;
  	d.year = +d.year;
  });
	render(data);
});